# Jupyno
Module permettant d'écrire et de téléverser des croquis Arduino directement depuis un notebook Jupyter.
Nécessite le programme arduino-cli (https://github.com/arduino/arduino-cli) présent dans le même dossier.